==> teachbooks-0.2.0b1-py3-none-any.whl: teachbooks/external_content/utils.py <==
from pathlib import Path
from typing import Any, Callable, Dict, overload

import yaml


@overload
def modify_field(
    data: dict, key: str, func: Callable, *args, **kwargs
) -> dict: ...


@overload
def modify_field(
    data: list, key: str, func: Callable, *args, **kwargs
) -> list: ...


def modify_field(
    data: dict | list, key: str, func: Callable, *args, **kwargs
) -> dict | list:
    """Modify the fields that match a given key.

    Recursively look for the fields matching a given key in a YAML-like
    mapping. Modify the matching fields by running `func` on them.

    :param data: mapping where to look for matches
    :param key: key to look for
    :param func: function to run on the matching fields
    :param args, kwargs: other positional and keyword arguments for `func`
    :return: modified mapping
    """
    if isinstance(data, dict):
        if key in data:
            return func(data, *args, **kwargs)
        else:
            return {
                k: modify_field(v, key, func, *args, **kwargs)
                for k, v in data.items()
            }
    elif isinstance(data, list):
        return [modify_field(el, key, func, *args, **kwargs) for el in data]
    return data


def load_yaml_file(
        path: str | Path, encoding: str = "utf8"
) -> Dict[str, Any]:
    """Load a yaml file file (ToC or config) as dictionary.

    :param path: file path
    :param encoding: file character encoding
    :return: parsed file
    """
    with open(path, encoding=encoding) as handle:
        data = yaml.safe_load(handle)
    return data

==> teachbooks-0.2.1-py3-none-any.whl: teachbooks/external_content/utils.py <==
"""Utilities for external content."""
from collections.abc import Callable
from pathlib import Path
from typing import Any, overload

import yaml


@overload
def modify_field(
    data: dict, key: str, func: Callable, *args, **kwargs
) -> dict: ...


@overload
def modify_field(
    data: list, key: str, func: Callable, *args, **kwargs
) -> list: ...


def modify_field(
    data: dict | list, key: str, func: Callable, *args, **kwargs
) -> dict | list:
    """Modify the fields that match a given key.

    Recursively look for the fields matching a given key in a YAML-like
    mapping. Modify the matching fields by running `func` on them.

    Args:
        data: mapping where to look for matches
        key: key to look for
        func: function to run on the matching fields
        args: positional arguments for `func`
        kwargs: keyword arguments for `func`
    
    Returns:
        modified mapping
    """
    if isinstance(data, dict):
        if key in data:
            return func(data, *args, **kwargs)
        else:
            return {
                k: modify_field(v, key, func, *args, **kwargs)
                for k, v in data.items()
            }
    elif isinstance(data, list):
        return [modify_field(el, key, func, *args, **kwargs) for el in data]
    return data


def load_yaml_file(
        path: str | Path, encoding: str = "utf8"
) -> dict[str, Any]:
    """Load a yaml file file (ToC or config) as dictionary.

    Args:
        path: file path
        encoding: file character encoding
    
    Returns:
        parsed file
    """
    with open(path, encoding=encoding) as handle:
        data = yaml.safe_load(handle)
    return data
